@@ -3,6 +3,30 @@ from enum import Enum
 
 
 user32 = ctypes.windll.user32
+kernel32 = ctypes.windll.kernel32
+gdi32 = ctypes.windll.gdi32
+
+
+# Number of units covered in 1 second
+WIZARD_SPEED = 580
+
+
+type_format_dict = {
+    "char": "<c",
+    "signed char": "<b",
+    "unsigned char": "<B",
+    "bool": "?",
+    "short": "<h",
+    "unsigned short": "<H",
+    "int": "<i",
+    "unsigned int": "<I",
+    "long": "<l",
+    "unsigned long": "<L",
+    "long long": "<q",
+    "unsigned long long": "<Q",
+    "float": "<f",
+    "double": "<d",
+}
 
 
 # noinspection PyPep8
