@@ -249,21 +249,17 @@ class QuestHook(SimpleHook):
 
 
 class DuelHook(SimpleHook):
-    pattern = (
-        rb"\x48\x89\x7C\x24\x58\x48\x89\x4C\x24\x50\x4C\x89\x7C\x24\x48\x89\x5C\x24\x40"
-    )
+    pattern = rb"\x48\x89\x5C\x24\x58\x48\x89\x44\x24\x50\x48"
     exports = [("current_duel_addr", 8)]
 
     async def bytecode_generator(self, packed_exports):
         # fmt: off
         bytecode = (
-                b"\x48\x39\xD1"  # cmp rcx,rdx
-                b"\x0F\x85\x10\x00\x00\x00"  # jne 16
                 b"\x50"  # push rax
-                b"\x49\x8B\x04\x24"  # mov rax,[r12]
+                b"\x49\x8B\x07"  # mov rax,[r15]
                 b"\x48\xA3" + packed_exports[0][1] +  # mov [current_duel],rax
                 b"\x58"  # pop rax
-                b"\x48\x89\x7C\x24\x58"  # original instruction
+                b"\x48\x89\x5C\x24\x58"  # original instruction
         )
         # fmt: on
 
@@ -437,7 +433,8 @@ class MouselessCursorMoveHook(User32GetClassInfoBaseHook):
             rb"\x00\xFF\x50\x18\x66\xC7", module="WizardGraphicalClient.exe"
         )
         bool_two_address = await self.pattern_scan(
-            rb"\xC6\x86...\x00.\x33\xFF", module="WizardGraphicalClient.exe",
+            rb"\xC6\x86...\x00.\x33\xFF",
+            module="WizardGraphicalClient.exe",
         )
 
         if bool_one_address is None or bool_two_address is None:
